"""
    OpenAPI definition

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v0
    Contact: support@gooddata.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from gooddata_api_client.api_client import ApiClient, Endpoint as _Endpoint
from gooddata_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from gooddata_api_client.model.declarative_analytics import DeclarativeAnalytics
from gooddata_api_client.model.declarative_data_sources import DeclarativeDataSources
from gooddata_api_client.model.declarative_model import DeclarativeModel
from gooddata_api_client.model.declarative_organization import DeclarativeOrganization
from gooddata_api_client.model.declarative_pdm import DeclarativePdm
from gooddata_api_client.model.declarative_user_groups import DeclarativeUserGroups
from gooddata_api_client.model.declarative_users import DeclarativeUsers
from gooddata_api_client.model.declarative_users_user_groups import DeclarativeUsersUserGroups
from gooddata_api_client.model.declarative_workspace_data_filters import DeclarativeWorkspaceDataFilters
from gooddata_api_client.model.declarative_workspace_model import DeclarativeWorkspaceModel
from gooddata_api_client.model.declarative_workspace_permissions import DeclarativeWorkspacePermissions
from gooddata_api_client.model.declarative_workspaces import DeclarativeWorkspaces


class LayoutApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_analytics_model_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeAnalytics,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/analyticsModel',
                'operation_id': 'get_analytics_model',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                ],
                'required': [
                    'workspace_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_data_sources_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeDataSources,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/dataSources',
                'operation_id': 'get_data_sources_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_logical_model_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeModel,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/logicalModel',
                'operation_id': 'get_logical_model',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'include_parents',
                ],
                'required': [
                    'workspace_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'include_parents':
                        (bool,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                    'include_parents': 'includeParents',
                },
                'location_map': {
                    'workspace_id': 'path',
                    'include_parents': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_organization_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeOrganization,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/organization',
                'operation_id': 'get_organization_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_pdm_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativePdm,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/dataSources/{dataSourceId}/physicalModel',
                'operation_id': 'get_pdm_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'data_source_id',
                ],
                'required': [
                    'data_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'data_source_id':
                        (str,),
                },
                'attribute_map': {
                    'data_source_id': 'dataSourceId',
                },
                'location_map': {
                    'data_source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_groups_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeUserGroups,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/userGroups',
                'operation_id': 'get_user_groups_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_users_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeUsers,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/users',
                'operation_id': 'get_users_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_users_user_groups_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeUsersUserGroups,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/usersAndUserGroups',
                'operation_id': 'get_users_user_groups_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspace_data_filters_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeWorkspaceDataFilters,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaceDataFilters',
                'operation_id': 'get_workspace_data_filters_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspace_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeWorkspaceModel,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}',
                'operation_id': 'get_workspace_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                ],
                'required': [
                    'workspace_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspace_permissions_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeWorkspacePermissions,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/permissions',
                'operation_id': 'get_workspace_permissions',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                ],
                'required': [
                    'workspace_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspaces_layout_endpoint = _Endpoint(
            settings={
                'response_type': (DeclarativeWorkspaces,),
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces',
                'operation_id': 'get_workspaces_layout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.put_data_sources_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/dataSources',
                'operation_id': 'put_data_sources_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_data_sources',
                ],
                'required': [
                    'declarative_data_sources',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_data_sources':
                        (DeclarativeDataSources,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_data_sources': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_user_groups_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/userGroups',
                'operation_id': 'put_user_groups_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_user_groups',
                ],
                'required': [
                    'declarative_user_groups',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_user_groups':
                        (DeclarativeUserGroups,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_user_groups': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_users_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/users',
                'operation_id': 'put_users_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_users',
                ],
                'required': [
                    'declarative_users',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_users':
                        (DeclarativeUsers,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_users': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_users_user_groups_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/usersAndUserGroups',
                'operation_id': 'put_users_user_groups_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_users_user_groups',
                ],
                'required': [
                    'declarative_users_user_groups',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_users_user_groups':
                        (DeclarativeUsersUserGroups,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_users_user_groups': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_workspace_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}',
                'operation_id': 'put_workspace_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'declarative_workspace_model',
                ],
                'required': [
                    'workspace_id',
                    'declarative_workspace_model',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'declarative_workspace_model':
                        (DeclarativeWorkspaceModel,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                    'declarative_workspace_model': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_analytics_model_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/analyticsModel',
                'operation_id': 'set_analytics_model',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'declarative_analytics',
                ],
                'required': [
                    'workspace_id',
                    'declarative_analytics',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'declarative_analytics':
                        (DeclarativeAnalytics,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                    'declarative_analytics': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_logical_model_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/logicalModel',
                'operation_id': 'set_logical_model',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'declarative_model',
                ],
                'required': [
                    'workspace_id',
                    'declarative_model',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'declarative_model':
                        (DeclarativeModel,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                    'declarative_model': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_organization_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/organization',
                'operation_id': 'set_organization_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_organization',
                ],
                'required': [
                    'declarative_organization',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_organization':
                        (DeclarativeOrganization,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_organization': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_pdm_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/dataSources/{dataSourceId}/physicalModel',
                'operation_id': 'set_pdm_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'data_source_id',
                    'declarative_pdm',
                ],
                'required': [
                    'data_source_id',
                    'declarative_pdm',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'data_source_id':
                        (str,),
                    'declarative_pdm':
                        (DeclarativePdm,),
                },
                'attribute_map': {
                    'data_source_id': 'dataSourceId',
                },
                'location_map': {
                    'data_source_id': 'path',
                    'declarative_pdm': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_workspace_data_filters_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaceDataFilters',
                'operation_id': 'set_workspace_data_filters_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_workspace_data_filters',
                ],
                'required': [
                    'declarative_workspace_data_filters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_workspace_data_filters':
                        (DeclarativeWorkspaceDataFilters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_workspace_data_filters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_workspace_permissions_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces/{workspaceId}/permissions',
                'operation_id': 'set_workspace_permissions',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'declarative_workspace_permissions',
                ],
                'required': [
                    'workspace_id',
                    'declarative_workspace_permissions',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'declarative_workspace_permissions':
                        (DeclarativeWorkspacePermissions,),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                },
                'location_map': {
                    'workspace_id': 'path',
                    'declarative_workspace_permissions': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.set_workspaces_layout_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/api/v1/layout/workspaces',
                'operation_id': 'set_workspaces_layout',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'declarative_workspaces',
                ],
                'required': [
                    'declarative_workspaces',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'declarative_workspaces':
                        (DeclarativeWorkspaces,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'declarative_workspaces': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_analytics_model(
        self,
        workspace_id,
        **kwargs
    ):
        """Get analytics model  # noqa: E501

        Retrieve current analytics model of the workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_analytics_model(workspace_id, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeAnalytics
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        return self.get_analytics_model_endpoint.call_with_http_info(**kwargs)

    def get_data_sources_layout(
        self,
        **kwargs
    ):
        """Get all data sources  # noqa: E501

        Retrieve all data sources including related physical model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_data_sources_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeDataSources
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_data_sources_layout_endpoint.call_with_http_info(**kwargs)

    def get_logical_model(
        self,
        workspace_id,
        **kwargs
    ):
        """Get logical model  # noqa: E501

        Retrieve current logical model of the workspace in declarative form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_logical_model(workspace_id, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):

        Keyword Args:
            include_parents (bool): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeModel
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        return self.get_logical_model_endpoint.call_with_http_info(**kwargs)

    def get_organization_layout(
        self,
        **kwargs
    ):
        """Get organization layout  # noqa: E501

        Retrieve complete layout of organization, workspaces, user-groups, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_organization_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeOrganization
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_organization_layout_endpoint.call_with_http_info(**kwargs)

    def get_pdm_layout(
        self,
        data_source_id,
        **kwargs
    ):
        """Get data source physical model layout  # noqa: E501

        Retrieve complete layout of tables with their columns  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_pdm_layout(data_source_id, async_req=True)
        >>> result = thread.get()

        Args:
            data_source_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativePdm
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['data_source_id'] = \
            data_source_id
        return self.get_pdm_layout_endpoint.call_with_http_info(**kwargs)

    def get_user_groups_layout(
        self,
        **kwargs
    ):
        """Get all user groups  # noqa: E501

        Retrieve all user-groups eventually with parent group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_groups_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeUserGroups
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_user_groups_layout_endpoint.call_with_http_info(**kwargs)

    def get_users_layout(
        self,
        **kwargs
    ):
        """Get all users  # noqa: E501

        Retrieve all users including authentication properties.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeUsers
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_users_layout_endpoint.call_with_http_info(**kwargs)

    def get_users_user_groups_layout(
        self,
        **kwargs
    ):
        """Get all users and user groups  # noqa: E501

        Retrieve all users and user groups with theirs properties.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_user_groups_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeUsersUserGroups
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_users_user_groups_layout_endpoint.call_with_http_info(**kwargs)

    def get_workspace_data_filters_layout(
        self,
        **kwargs
    ):
        """Get workspace data filters for all workspaces  # noqa: E501

        Retrieve all workspaces and related workspace data filters (and their settings / values).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspace_data_filters_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeWorkspaceDataFilters
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_workspace_data_filters_layout_endpoint.call_with_http_info(**kwargs)

    def get_workspace_layout(
        self,
        workspace_id,
        **kwargs
    ):
        """Get workspace layout  # noqa: E501

        Retrieve current model of the workspace in declarative form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspace_layout(workspace_id, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeWorkspaceModel
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        return self.get_workspace_layout_endpoint.call_with_http_info(**kwargs)

    def get_workspace_permissions(
        self,
        workspace_id,
        **kwargs
    ):
        """Get permissions for the workspace  # noqa: E501

        Retrieve current set of permissions of the workspace in a declarative form.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspace_permissions(workspace_id, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeWorkspacePermissions
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        return self.get_workspace_permissions_endpoint.call_with_http_info(**kwargs)

    def get_workspaces_layout(
        self,
        **kwargs
    ):
        """Get all workspaces layout  # noqa: E501

        Gets complete layout of workspaces, their hierarchy, models.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspaces_layout(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeclarativeWorkspaces
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_workspaces_layout_endpoint.call_with_http_info(**kwargs)

    def put_data_sources_layout(
        self,
        declarative_data_sources,
        **kwargs
    ):
        """Put all data sources  # noqa: E501

        Set all data sources including related physical model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_data_sources_layout(declarative_data_sources, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_data_sources (DeclarativeDataSources):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_data_sources'] = \
            declarative_data_sources
        return self.put_data_sources_layout_endpoint.call_with_http_info(**kwargs)

    def put_user_groups_layout(
        self,
        declarative_user_groups,
        **kwargs
    ):
        """Put all user groups  # noqa: E501

        Define all user groups with their parents eventually.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_user_groups_layout(declarative_user_groups, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_user_groups (DeclarativeUserGroups):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_user_groups'] = \
            declarative_user_groups
        return self.put_user_groups_layout_endpoint.call_with_http_info(**kwargs)

    def put_users_layout(
        self,
        declarative_users,
        **kwargs
    ):
        """Put all users  # noqa: E501

        Set all users and their authentication properties.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_layout(declarative_users, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_users (DeclarativeUsers):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_users'] = \
            declarative_users
        return self.put_users_layout_endpoint.call_with_http_info(**kwargs)

    def put_users_user_groups_layout(
        self,
        declarative_users_user_groups,
        **kwargs
    ):
        """Put all users and user groups  # noqa: E501

        Define all users and user groups with theirs properties.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_user_groups_layout(declarative_users_user_groups, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_users_user_groups (DeclarativeUsersUserGroups):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_users_user_groups'] = \
            declarative_users_user_groups
        return self.put_users_user_groups_layout_endpoint.call_with_http_info(**kwargs)

    def put_workspace_layout(
        self,
        workspace_id,
        declarative_workspace_model,
        **kwargs
    ):
        """Set workspace layout  # noqa: E501

        Set complete layout of workspace, like model, authorization, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_workspace_layout(workspace_id, declarative_workspace_model, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):
            declarative_workspace_model (DeclarativeWorkspaceModel):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        kwargs['declarative_workspace_model'] = \
            declarative_workspace_model
        return self.put_workspace_layout_endpoint.call_with_http_info(**kwargs)

    def set_analytics_model(
        self,
        workspace_id,
        declarative_analytics,
        **kwargs
    ):
        """Set analytics model  # noqa: E501

        Set effective analytics model of the workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_analytics_model(workspace_id, declarative_analytics, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):
            declarative_analytics (DeclarativeAnalytics):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        kwargs['declarative_analytics'] = \
            declarative_analytics
        return self.set_analytics_model_endpoint.call_with_http_info(**kwargs)

    def set_logical_model(
        self,
        workspace_id,
        declarative_model,
        **kwargs
    ):
        """Set logical model  # noqa: E501

        Set effective logical model of the workspace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_logical_model(workspace_id, declarative_model, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):
            declarative_model (DeclarativeModel):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        kwargs['declarative_model'] = \
            declarative_model
        return self.set_logical_model_endpoint.call_with_http_info(**kwargs)

    def set_organization_layout(
        self,
        declarative_organization,
        **kwargs
    ):
        """Set organization layout  # noqa: E501

        Sets complete layout of organization, like workspaces, user-groups, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_organization_layout(declarative_organization, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_organization (DeclarativeOrganization):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_organization'] = \
            declarative_organization
        return self.set_organization_layout_endpoint.call_with_http_info(**kwargs)

    def set_pdm_layout(
        self,
        data_source_id,
        declarative_pdm,
        **kwargs
    ):
        """Set data source physical model layout  # noqa: E501

        Sets complete layout of tables with their columns under corresponding Data Source.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_pdm_layout(data_source_id, declarative_pdm, async_req=True)
        >>> result = thread.get()

        Args:
            data_source_id (str):
            declarative_pdm (DeclarativePdm):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['data_source_id'] = \
            data_source_id
        kwargs['declarative_pdm'] = \
            declarative_pdm
        return self.set_pdm_layout_endpoint.call_with_http_info(**kwargs)

    def set_workspace_data_filters_layout(
        self,
        declarative_workspace_data_filters,
        **kwargs
    ):
        """Set all workspace data filters  # noqa: E501

        Sets workspace data filters in all workspaces in entire organization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_workspace_data_filters_layout(declarative_workspace_data_filters, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_workspace_data_filters (DeclarativeWorkspaceDataFilters):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_workspace_data_filters'] = \
            declarative_workspace_data_filters
        return self.set_workspace_data_filters_layout_endpoint.call_with_http_info(**kwargs)

    def set_workspace_permissions(
        self,
        workspace_id,
        declarative_workspace_permissions,
        **kwargs
    ):
        """Set permissions for the workspace  # noqa: E501

        Set effective permissions for the workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_workspace_permissions(workspace_id, declarative_workspace_permissions, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_id (str):
            declarative_workspace_permissions (DeclarativeWorkspacePermissions):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['workspace_id'] = \
            workspace_id
        kwargs['declarative_workspace_permissions'] = \
            declarative_workspace_permissions
        return self.set_workspace_permissions_endpoint.call_with_http_info(**kwargs)

    def set_workspaces_layout(
        self,
        declarative_workspaces,
        **kwargs
    ):
        """Set all workspaces layout  # noqa: E501

        Sets complete layout of workspaces, their hierarchy, models.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_workspaces_layout(declarative_workspaces, async_req=True)
        >>> result = thread.get()

        Args:
            declarative_workspaces (DeclarativeWorkspaces):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['declarative_workspaces'] = \
            declarative_workspaces
        return self.set_workspaces_layout_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from gooddata_api_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from gooddata_api_client.model.afm import AFM
from gooddata_api_client.model.absolute_date_filter import AbsoluteDateFilter
from gooddata_api_client.model.absolute_date_filter_absolute_date_filter import AbsoluteDateFilterAbsoluteDateFilter
from gooddata_api_client.model.abstract_measure_value_filter import AbstractMeasureValueFilter
from gooddata_api_client.model.afm_execution import AfmExecution
from gooddata_api_client.model.afm_execution_response import AfmExecutionResponse
from gooddata_api_client.model.afm_identifier import AfmIdentifier
from gooddata_api_client.model.afm_local_identifier import AfmLocalIdentifier
from gooddata_api_client.model.afm_object_identifier import AfmObjectIdentifier
from gooddata_api_client.model.afm_object_identifier_attribute import AfmObjectIdentifierAttribute
from gooddata_api_client.model.afm_object_identifier_attribute_identifier import AfmObjectIdentifierAttributeIdentifier
from gooddata_api_client.model.afm_object_identifier_core import AfmObjectIdentifierCore
from gooddata_api_client.model.afm_object_identifier_core_identifier import AfmObjectIdentifierCoreIdentifier
from gooddata_api_client.model.afm_object_identifier_dataset import AfmObjectIdentifierDataset
from gooddata_api_client.model.afm_object_identifier_dataset_identifier import AfmObjectIdentifierDatasetIdentifier
from gooddata_api_client.model.afm_object_identifier_identifier import AfmObjectIdentifierIdentifier
from gooddata_api_client.model.afm_object_identifier_label import AfmObjectIdentifierLabel
from gooddata_api_client.model.afm_object_identifier_label_identifier import AfmObjectIdentifierLabelIdentifier
from gooddata_api_client.model.afm_valid_objects_query import AfmValidObjectsQuery
from gooddata_api_client.model.afm_valid_objects_response import AfmValidObjectsResponse
from gooddata_api_client.model.api_entitlement import ApiEntitlement
from gooddata_api_client.model.arithmetic_measure_definition import ArithmeticMeasureDefinition
from gooddata_api_client.model.arithmetic_measure_definition_arithmetic_measure import ArithmeticMeasureDefinitionArithmeticMeasure
from gooddata_api_client.model.assignee_identifier import AssigneeIdentifier
from gooddata_api_client.model.attribute_execution_result_header import AttributeExecutionResultHeader
from gooddata_api_client.model.attribute_filter import AttributeFilter
from gooddata_api_client.model.attribute_filter_elements import AttributeFilterElements
from gooddata_api_client.model.attribute_format import AttributeFormat
from gooddata_api_client.model.attribute_header_out import AttributeHeaderOut
from gooddata_api_client.model.attribute_header_out_attribute_header import AttributeHeaderOutAttributeHeader
from gooddata_api_client.model.attribute_item import AttributeItem
from gooddata_api_client.model.attribute_result_header import AttributeResultHeader
from gooddata_api_client.model.column_warning import ColumnWarning
from gooddata_api_client.model.comparison_measure_value_filter import ComparisonMeasureValueFilter
from gooddata_api_client.model.comparison_measure_value_filter_comparison_measure_value_filter import ComparisonMeasureValueFilterComparisonMeasureValueFilter
from gooddata_api_client.model.custom_label import CustomLabel
from gooddata_api_client.model.custom_metric import CustomMetric
from gooddata_api_client.model.custom_override import CustomOverride
from gooddata_api_client.model.data_column_locator import DataColumnLocator
from gooddata_api_client.model.data_column_locators import DataColumnLocators
from gooddata_api_client.model.data_source_parameter import DataSourceParameter
from gooddata_api_client.model.data_source_schemata import DataSourceSchemata
from gooddata_api_client.model.data_source_table_identifier import DataSourceTableIdentifier
from gooddata_api_client.model.dataset_reference_identifier import DatasetReferenceIdentifier
from gooddata_api_client.model.date_filter import DateFilter
from gooddata_api_client.model.declarative_analytical_dashboard import DeclarativeAnalyticalDashboard
from gooddata_api_client.model.declarative_analytics import DeclarativeAnalytics
from gooddata_api_client.model.declarative_analytics_layer import DeclarativeAnalyticsLayer
from gooddata_api_client.model.declarative_attribute import DeclarativeAttribute
from gooddata_api_client.model.declarative_color_palette import DeclarativeColorPalette
from gooddata_api_client.model.declarative_column import DeclarativeColumn
from gooddata_api_client.model.declarative_csp_directive import DeclarativeCspDirective
from gooddata_api_client.model.declarative_custom_application_setting import DeclarativeCustomApplicationSetting
from gooddata_api_client.model.declarative_dashboard_plugin import DeclarativeDashboardPlugin
from gooddata_api_client.model.declarative_data_source import DeclarativeDataSource
from gooddata_api_client.model.declarative_data_source_permission import DeclarativeDataSourcePermission
from gooddata_api_client.model.declarative_data_sources import DeclarativeDataSources
from gooddata_api_client.model.declarative_dataset import DeclarativeDataset
from gooddata_api_client.model.declarative_date_dataset import DeclarativeDateDataset
from gooddata_api_client.model.declarative_fact import DeclarativeFact
from gooddata_api_client.model.declarative_filter_context import DeclarativeFilterContext
from gooddata_api_client.model.declarative_label import DeclarativeLabel
from gooddata_api_client.model.declarative_ldm import DeclarativeLdm
from gooddata_api_client.model.declarative_metric import DeclarativeMetric
from gooddata_api_client.model.declarative_model import DeclarativeModel
from gooddata_api_client.model.declarative_organization import DeclarativeOrganization
from gooddata_api_client.model.declarative_organization_info import DeclarativeOrganizationInfo
from gooddata_api_client.model.declarative_organization_permission import DeclarativeOrganizationPermission
from gooddata_api_client.model.declarative_pdm import DeclarativePdm
from gooddata_api_client.model.declarative_reference import DeclarativeReference
from gooddata_api_client.model.declarative_setting import DeclarativeSetting
from gooddata_api_client.model.declarative_single_workspace_permission import DeclarativeSingleWorkspacePermission
from gooddata_api_client.model.declarative_table import DeclarativeTable
from gooddata_api_client.model.declarative_tables import DeclarativeTables
from gooddata_api_client.model.declarative_theme import DeclarativeTheme
from gooddata_api_client.model.declarative_user import DeclarativeUser
from gooddata_api_client.model.declarative_user_group import DeclarativeUserGroup
from gooddata_api_client.model.declarative_user_groups import DeclarativeUserGroups
from gooddata_api_client.model.declarative_users import DeclarativeUsers
from gooddata_api_client.model.declarative_users_user_groups import DeclarativeUsersUserGroups
from gooddata_api_client.model.declarative_visualization_object import DeclarativeVisualizationObject
from gooddata_api_client.model.declarative_workspace import DeclarativeWorkspace
from gooddata_api_client.model.declarative_workspace_data_filter import DeclarativeWorkspaceDataFilter
from gooddata_api_client.model.declarative_workspace_data_filter_setting import DeclarativeWorkspaceDataFilterSetting
from gooddata_api_client.model.declarative_workspace_data_filters import DeclarativeWorkspaceDataFilters
from gooddata_api_client.model.declarative_workspace_hierarchy_permission import DeclarativeWorkspaceHierarchyPermission
from gooddata_api_client.model.declarative_workspace_model import DeclarativeWorkspaceModel
from gooddata_api_client.model.declarative_workspace_permissions import DeclarativeWorkspacePermissions
from gooddata_api_client.model.declarative_workspaces import DeclarativeWorkspaces
from gooddata_api_client.model.dependent_entities_graph import DependentEntitiesGraph
from gooddata_api_client.model.dependent_entities_node import DependentEntitiesNode
from gooddata_api_client.model.dependent_entities_request import DependentEntitiesRequest
from gooddata_api_client.model.dependent_entities_response import DependentEntitiesResponse
from gooddata_api_client.model.dimension import Dimension
from gooddata_api_client.model.dimension_header import DimensionHeader
from gooddata_api_client.model.element import Element
from gooddata_api_client.model.elements_request import ElementsRequest
from gooddata_api_client.model.elements_response import ElementsResponse
from gooddata_api_client.model.entitlements_request import EntitlementsRequest
from gooddata_api_client.model.entity_identifier import EntityIdentifier
from gooddata_api_client.model.execution_links import ExecutionLinks
from gooddata_api_client.model.execution_response import ExecutionResponse
from gooddata_api_client.model.execution_result import ExecutionResult
from gooddata_api_client.model.execution_result_grand_total import ExecutionResultGrandTotal
from gooddata_api_client.model.execution_result_header import ExecutionResultHeader
from gooddata_api_client.model.execution_result_paging import ExecutionResultPaging
from gooddata_api_client.model.execution_settings import ExecutionSettings
from gooddata_api_client.model.filter_by import FilterBy
from gooddata_api_client.model.filter_definition import FilterDefinition
from gooddata_api_client.model.filter_definition_for_simple_measure import FilterDefinitionForSimpleMeasure
from gooddata_api_client.model.generate_ldm_request import GenerateLdmRequest
from gooddata_api_client.model.grain_identifier import GrainIdentifier
from gooddata_api_client.model.granularities_formatting import GranularitiesFormatting
from gooddata_api_client.model.header_group import HeaderGroup
from gooddata_api_client.model.inline_filter_definition import InlineFilterDefinition
from gooddata_api_client.model.inline_filter_definition_inline import InlineFilterDefinitionInline
from gooddata_api_client.model.inline_measure_definition import InlineMeasureDefinition
from gooddata_api_client.model.inline_measure_definition_inline import InlineMeasureDefinitionInline
from gooddata_api_client.model.json_api_analytical_dashboard_in import JsonApiAnalyticalDashboardIn
from gooddata_api_client.model.json_api_analytical_dashboard_in_attributes import JsonApiAnalyticalDashboardInAttributes
from gooddata_api_client.model.json_api_analytical_dashboard_in_document import JsonApiAnalyticalDashboardInDocument
from gooddata_api_client.model.json_api_analytical_dashboard_linkage import JsonApiAnalyticalDashboardLinkage
from gooddata_api_client.model.json_api_analytical_dashboard_out import JsonApiAnalyticalDashboardOut
from gooddata_api_client.model.json_api_analytical_dashboard_out_document import JsonApiAnalyticalDashboardOutDocument
from gooddata_api_client.model.json_api_analytical_dashboard_out_includes import JsonApiAnalyticalDashboardOutIncludes
from gooddata_api_client.model.json_api_analytical_dashboard_out_list import JsonApiAnalyticalDashboardOutList
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships import JsonApiAnalyticalDashboardOutRelationships
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_analytical_dashboards import JsonApiAnalyticalDashboardOutRelationshipsAnalyticalDashboards
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_dashboard_plugins import JsonApiAnalyticalDashboardOutRelationshipsDashboardPlugins
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_datasets import JsonApiAnalyticalDashboardOutRelationshipsDatasets
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_filter_contexts import JsonApiAnalyticalDashboardOutRelationshipsFilterContexts
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_labels import JsonApiAnalyticalDashboardOutRelationshipsLabels
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_metrics import JsonApiAnalyticalDashboardOutRelationshipsMetrics
from gooddata_api_client.model.json_api_analytical_dashboard_out_relationships_visualization_objects import JsonApiAnalyticalDashboardOutRelationshipsVisualizationObjects
from gooddata_api_client.model.json_api_analytical_dashboard_out_with_links import JsonApiAnalyticalDashboardOutWithLinks
from gooddata_api_client.model.json_api_analytical_dashboard_patch import JsonApiAnalyticalDashboardPatch
from gooddata_api_client.model.json_api_analytical_dashboard_patch_document import JsonApiAnalyticalDashboardPatchDocument
from gooddata_api_client.model.json_api_analytical_dashboard_to_many_linkage import JsonApiAnalyticalDashboardToManyLinkage
from gooddata_api_client.model.json_api_api_token_in import JsonApiApiTokenIn
from gooddata_api_client.model.json_api_api_token_in_document import JsonApiApiTokenInDocument
from gooddata_api_client.model.json_api_api_token_out import JsonApiApiTokenOut
from gooddata_api_client.model.json_api_api_token_out_attributes import JsonApiApiTokenOutAttributes
from gooddata_api_client.model.json_api_api_token_out_document import JsonApiApiTokenOutDocument
from gooddata_api_client.model.json_api_api_token_out_list import JsonApiApiTokenOutList
from gooddata_api_client.model.json_api_api_token_out_with_links import JsonApiApiTokenOutWithLinks
from gooddata_api_client.model.json_api_attribute_linkage import JsonApiAttributeLinkage
from gooddata_api_client.model.json_api_attribute_out import JsonApiAttributeOut
from gooddata_api_client.model.json_api_attribute_out_attributes import JsonApiAttributeOutAttributes
from gooddata_api_client.model.json_api_attribute_out_document import JsonApiAttributeOutDocument
from gooddata_api_client.model.json_api_attribute_out_includes import JsonApiAttributeOutIncludes
from gooddata_api_client.model.json_api_attribute_out_list import JsonApiAttributeOutList
from gooddata_api_client.model.json_api_attribute_out_relationships import JsonApiAttributeOutRelationships
from gooddata_api_client.model.json_api_attribute_out_relationships_dataset import JsonApiAttributeOutRelationshipsDataset
from gooddata_api_client.model.json_api_attribute_out_relationships_default_view import JsonApiAttributeOutRelationshipsDefaultView
from gooddata_api_client.model.json_api_attribute_out_with_links import JsonApiAttributeOutWithLinks
from gooddata_api_client.model.json_api_attribute_to_many_linkage import JsonApiAttributeToManyLinkage
from gooddata_api_client.model.json_api_attribute_to_one_linkage import JsonApiAttributeToOneLinkage
from gooddata_api_client.model.json_api_color_palette_in import JsonApiColorPaletteIn
from gooddata_api_client.model.json_api_color_palette_in_attributes import JsonApiColorPaletteInAttributes
from gooddata_api_client.model.json_api_color_palette_in_document import JsonApiColorPaletteInDocument
from gooddata_api_client.model.json_api_color_palette_out import JsonApiColorPaletteOut
from gooddata_api_client.model.json_api_color_palette_out_document import JsonApiColorPaletteOutDocument
from gooddata_api_client.model.json_api_color_palette_out_list import JsonApiColorPaletteOutList
from gooddata_api_client.model.json_api_color_palette_out_with_links import JsonApiColorPaletteOutWithLinks
from gooddata_api_client.model.json_api_color_palette_patch import JsonApiColorPalettePatch
from gooddata_api_client.model.json_api_color_palette_patch_attributes import JsonApiColorPalettePatchAttributes
from gooddata_api_client.model.json_api_color_palette_patch_document import JsonApiColorPalettePatchDocument
from gooddata_api_client.model.json_api_cookie_security_configuration_in import JsonApiCookieSecurityConfigurationIn
from gooddata_api_client.model.json_api_cookie_security_configuration_in_attributes import JsonApiCookieSecurityConfigurationInAttributes
from gooddata_api_client.model.json_api_cookie_security_configuration_in_document import JsonApiCookieSecurityConfigurationInDocument
from gooddata_api_client.model.json_api_cookie_security_configuration_out import JsonApiCookieSecurityConfigurationOut
from gooddata_api_client.model.json_api_cookie_security_configuration_out_document import JsonApiCookieSecurityConfigurationOutDocument
from gooddata_api_client.model.json_api_cookie_security_configuration_patch import JsonApiCookieSecurityConfigurationPatch
from gooddata_api_client.model.json_api_cookie_security_configuration_patch_document import JsonApiCookieSecurityConfigurationPatchDocument
from gooddata_api_client.model.json_api_csp_directive_in import JsonApiCspDirectiveIn
from gooddata_api_client.model.json_api_csp_directive_in_attributes import JsonApiCspDirectiveInAttributes
from gooddata_api_client.model.json_api_csp_directive_in_document import JsonApiCspDirectiveInDocument
from gooddata_api_client.model.json_api_csp_directive_out import JsonApiCspDirectiveOut
from gooddata_api_client.model.json_api_csp_directive_out_document import JsonApiCspDirectiveOutDocument
from gooddata_api_client.model.json_api_csp_directive_out_list import JsonApiCspDirectiveOutList
from gooddata_api_client.model.json_api_csp_directive_out_with_links import JsonApiCspDirectiveOutWithLinks
from gooddata_api_client.model.json_api_csp_directive_patch import JsonApiCspDirectivePatch
from gooddata_api_client.model.json_api_csp_directive_patch_attributes import JsonApiCspDirectivePatchAttributes
from gooddata_api_client.model.json_api_csp_directive_patch_document import JsonApiCspDirectivePatchDocument
from gooddata_api_client.model.json_api_custom_application_setting_in import JsonApiCustomApplicationSettingIn
from gooddata_api_client.model.json_api_custom_application_setting_in_attributes import JsonApiCustomApplicationSettingInAttributes
from gooddata_api_client.model.json_api_custom_application_setting_in_document import JsonApiCustomApplicationSettingInDocument
from gooddata_api_client.model.json_api_custom_application_setting_out import JsonApiCustomApplicationSettingOut
from gooddata_api_client.model.json_api_custom_application_setting_out_document import JsonApiCustomApplicationSettingOutDocument
from gooddata_api_client.model.json_api_custom_application_setting_out_list import JsonApiCustomApplicationSettingOutList
from gooddata_api_client.model.json_api_custom_application_setting_out_with_links import JsonApiCustomApplicationSettingOutWithLinks
from gooddata_api_client.model.json_api_custom_application_setting_patch import JsonApiCustomApplicationSettingPatch
from gooddata_api_client.model.json_api_custom_application_setting_patch_attributes import JsonApiCustomApplicationSettingPatchAttributes
from gooddata_api_client.model.json_api_custom_application_setting_patch_document import JsonApiCustomApplicationSettingPatchDocument
from gooddata_api_client.model.json_api_dashboard_plugin_in import JsonApiDashboardPluginIn
from gooddata_api_client.model.json_api_dashboard_plugin_in_attributes import JsonApiDashboardPluginInAttributes
from gooddata_api_client.model.json_api_dashboard_plugin_in_document import JsonApiDashboardPluginInDocument
from gooddata_api_client.model.json_api_dashboard_plugin_linkage import JsonApiDashboardPluginLinkage
from gooddata_api_client.model.json_api_dashboard_plugin_out import JsonApiDashboardPluginOut
from gooddata_api_client.model.json_api_dashboard_plugin_out_document import JsonApiDashboardPluginOutDocument
from gooddata_api_client.model.json_api_dashboard_plugin_out_list import JsonApiDashboardPluginOutList
from gooddata_api_client.model.json_api_dashboard_plugin_out_with_links import JsonApiDashboardPluginOutWithLinks
from gooddata_api_client.model.json_api_dashboard_plugin_patch import JsonApiDashboardPluginPatch
from gooddata_api_client.model.json_api_dashboard_plugin_patch_document import JsonApiDashboardPluginPatchDocument
from gooddata_api_client.model.json_api_dashboard_plugin_to_many_linkage import JsonApiDashboardPluginToManyLinkage
from gooddata_api_client.model.json_api_data_source_identifier_out import JsonApiDataSourceIdentifierOut
from gooddata_api_client.model.json_api_data_source_identifier_out_attributes import JsonApiDataSourceIdentifierOutAttributes
from gooddata_api_client.model.json_api_data_source_identifier_out_document import JsonApiDataSourceIdentifierOutDocument
from gooddata_api_client.model.json_api_data_source_identifier_out_list import JsonApiDataSourceIdentifierOutList
from gooddata_api_client.model.json_api_data_source_identifier_out_meta import JsonApiDataSourceIdentifierOutMeta
from gooddata_api_client.model.json_api_data_source_identifier_out_with_links import JsonApiDataSourceIdentifierOutWithLinks
from gooddata_api_client.model.json_api_data_source_in import JsonApiDataSourceIn
from gooddata_api_client.model.json_api_data_source_in_attributes import JsonApiDataSourceInAttributes
from gooddata_api_client.model.json_api_data_source_in_attributes_parameters_inner import JsonApiDataSourceInAttributesParametersInner
from gooddata_api_client.model.json_api_data_source_in_document import JsonApiDataSourceInDocument
from gooddata_api_client.model.json_api_data_source_out import JsonApiDataSourceOut
from gooddata_api_client.model.json_api_data_source_out_attributes import JsonApiDataSourceOutAttributes
from gooddata_api_client.model.json_api_data_source_out_document import JsonApiDataSourceOutDocument
from gooddata_api_client.model.json_api_data_source_out_list import JsonApiDataSourceOutList
from gooddata_api_client.model.json_api_data_source_out_with_links import JsonApiDataSourceOutWithLinks
from gooddata_api_client.model.json_api_data_source_patch import JsonApiDataSourcePatch
from gooddata_api_client.model.json_api_data_source_patch_attributes import JsonApiDataSourcePatchAttributes
from gooddata_api_client.model.json_api_data_source_patch_document import JsonApiDataSourcePatchDocument
from gooddata_api_client.model.json_api_data_source_table_out import JsonApiDataSourceTableOut
from gooddata_api_client.model.json_api_data_source_table_out_attributes import JsonApiDataSourceTableOutAttributes
from gooddata_api_client.model.json_api_data_source_table_out_attributes_columns_inner import JsonApiDataSourceTableOutAttributesColumnsInner
from gooddata_api_client.model.json_api_data_source_table_out_document import JsonApiDataSourceTableOutDocument
from gooddata_api_client.model.json_api_data_source_table_out_list import JsonApiDataSourceTableOutList
from gooddata_api_client.model.json_api_data_source_table_out_with_links import JsonApiDataSourceTableOutWithLinks
from gooddata_api_client.model.json_api_dataset_linkage import JsonApiDatasetLinkage
from gooddata_api_client.model.json_api_dataset_out import JsonApiDatasetOut
from gooddata_api_client.model.json_api_dataset_out_attributes import JsonApiDatasetOutAttributes
from gooddata_api_client.model.json_api_dataset_out_attributes_grain_inner import JsonApiDatasetOutAttributesGrainInner
from gooddata_api_client.model.json_api_dataset_out_attributes_reference_properties_inner import JsonApiDatasetOutAttributesReferencePropertiesInner
from gooddata_api_client.model.json_api_dataset_out_document import JsonApiDatasetOutDocument
from gooddata_api_client.model.json_api_dataset_out_includes import JsonApiDatasetOutIncludes
from gooddata_api_client.model.json_api_dataset_out_list import JsonApiDatasetOutList
from gooddata_api_client.model.json_api_dataset_out_relationships import JsonApiDatasetOutRelationships
from gooddata_api_client.model.json_api_dataset_out_relationships_attributes import JsonApiDatasetOutRelationshipsAttributes
from gooddata_api_client.model.json_api_dataset_out_relationships_facts import JsonApiDatasetOutRelationshipsFacts
from gooddata_api_client.model.json_api_dataset_out_with_links import JsonApiDatasetOutWithLinks
from gooddata_api_client.model.json_api_dataset_to_many_linkage import JsonApiDatasetToManyLinkage
from gooddata_api_client.model.json_api_dataset_to_one_linkage import JsonApiDatasetToOneLinkage
from gooddata_api_client.model.json_api_entitlement_out import JsonApiEntitlementOut
from gooddata_api_client.model.json_api_entitlement_out_attributes import JsonApiEntitlementOutAttributes
from gooddata_api_client.model.json_api_entitlement_out_document import JsonApiEntitlementOutDocument
from gooddata_api_client.model.json_api_entitlement_out_list import JsonApiEntitlementOutList
from gooddata_api_client.model.json_api_entitlement_out_with_links import JsonApiEntitlementOutWithLinks
from gooddata_api_client.model.json_api_fact_linkage import JsonApiFactLinkage
from gooddata_api_client.model.json_api_fact_out import JsonApiFactOut
from gooddata_api_client.model.json_api_fact_out_attributes import JsonApiFactOutAttributes
from gooddata_api_client.model.json_api_fact_out_document import JsonApiFactOutDocument
from gooddata_api_client.model.json_api_fact_out_list import JsonApiFactOutList
from gooddata_api_client.model.json_api_fact_out_relationships import JsonApiFactOutRelationships
from gooddata_api_client.model.json_api_fact_out_with_links import JsonApiFactOutWithLinks
from gooddata_api_client.model.json_api_fact_to_many_linkage import JsonApiFactToManyLinkage
from gooddata_api_client.model.json_api_filter_context_in import JsonApiFilterContextIn
from gooddata_api_client.model.json_api_filter_context_in_document import JsonApiFilterContextInDocument
from gooddata_api_client.model.json_api_filter_context_linkage import JsonApiFilterContextLinkage
from gooddata_api_client.model.json_api_filter_context_out import JsonApiFilterContextOut
from gooddata_api_client.model.json_api_filter_context_out_document import JsonApiFilterContextOutDocument
from gooddata_api_client.model.json_api_filter_context_out_includes import JsonApiFilterContextOutIncludes
from gooddata_api_client.model.json_api_filter_context_out_list import JsonApiFilterContextOutList
from gooddata_api_client.model.json_api_filter_context_out_relationships import JsonApiFilterContextOutRelationships
from gooddata_api_client.model.json_api_filter_context_out_with_links import JsonApiFilterContextOutWithLinks
from gooddata_api_client.model.json_api_filter_context_patch import JsonApiFilterContextPatch
from gooddata_api_client.model.json_api_filter_context_patch_document import JsonApiFilterContextPatchDocument
from gooddata_api_client.model.json_api_filter_context_to_many_linkage import JsonApiFilterContextToManyLinkage
from gooddata_api_client.model.json_api_label_linkage import JsonApiLabelLinkage
from gooddata_api_client.model.json_api_label_out import JsonApiLabelOut
from gooddata_api_client.model.json_api_label_out_attributes import JsonApiLabelOutAttributes
from gooddata_api_client.model.json_api_label_out_document import JsonApiLabelOutDocument
from gooddata_api_client.model.json_api_label_out_list import JsonApiLabelOutList
from gooddata_api_client.model.json_api_label_out_relationships import JsonApiLabelOutRelationships
from gooddata_api_client.model.json_api_label_out_relationships_attribute import JsonApiLabelOutRelationshipsAttribute
from gooddata_api_client.model.json_api_label_out_with_links import JsonApiLabelOutWithLinks
from gooddata_api_client.model.json_api_label_to_many_linkage import JsonApiLabelToManyLinkage
from gooddata_api_client.model.json_api_label_to_one_linkage import JsonApiLabelToOneLinkage
from gooddata_api_client.model.json_api_metric_in import JsonApiMetricIn
from gooddata_api_client.model.json_api_metric_in_attributes import JsonApiMetricInAttributes
from gooddata_api_client.model.json_api_metric_in_attributes_content import JsonApiMetricInAttributesContent
from gooddata_api_client.model.json_api_metric_in_document import JsonApiMetricInDocument
from gooddata_api_client.model.json_api_metric_linkage import JsonApiMetricLinkage
from gooddata_api_client.model.json_api_metric_out import JsonApiMetricOut
from gooddata_api_client.model.json_api_metric_out_document import JsonApiMetricOutDocument
from gooddata_api_client.model.json_api_metric_out_includes import JsonApiMetricOutIncludes
from gooddata_api_client.model.json_api_metric_out_list import JsonApiMetricOutList
from gooddata_api_client.model.json_api_metric_out_relationships import JsonApiMetricOutRelationships
from gooddata_api_client.model.json_api_metric_out_with_links import JsonApiMetricOutWithLinks
from gooddata_api_client.model.json_api_metric_patch import JsonApiMetricPatch
from gooddata_api_client.model.json_api_metric_patch_attributes import JsonApiMetricPatchAttributes
from gooddata_api_client.model.json_api_metric_patch_document import JsonApiMetricPatchDocument
from gooddata_api_client.model.json_api_metric_to_many_linkage import JsonApiMetricToManyLinkage
from gooddata_api_client.model.json_api_organization_in import JsonApiOrganizationIn
from gooddata_api_client.model.json_api_organization_in_attributes import JsonApiOrganizationInAttributes
from gooddata_api_client.model.json_api_organization_in_document import JsonApiOrganizationInDocument
from gooddata_api_client.model.json_api_organization_out import JsonApiOrganizationOut
from gooddata_api_client.model.json_api_organization_out_attributes import JsonApiOrganizationOutAttributes
from gooddata_api_client.model.json_api_organization_out_document import JsonApiOrganizationOutDocument
from gooddata_api_client.model.json_api_organization_out_includes import JsonApiOrganizationOutIncludes
from gooddata_api_client.model.json_api_organization_out_meta import JsonApiOrganizationOutMeta
from gooddata_api_client.model.json_api_organization_out_relationships import JsonApiOrganizationOutRelationships
from gooddata_api_client.model.json_api_organization_out_relationships_bootstrap_user import JsonApiOrganizationOutRelationshipsBootstrapUser
from gooddata_api_client.model.json_api_organization_out_relationships_bootstrap_user_group import JsonApiOrganizationOutRelationshipsBootstrapUserGroup
from gooddata_api_client.model.json_api_organization_patch import JsonApiOrganizationPatch
from gooddata_api_client.model.json_api_organization_patch_document import JsonApiOrganizationPatchDocument
from gooddata_api_client.model.json_api_organization_setting_in import JsonApiOrganizationSettingIn
from gooddata_api_client.model.json_api_organization_setting_in_attributes import JsonApiOrganizationSettingInAttributes
from gooddata_api_client.model.json_api_organization_setting_in_document import JsonApiOrganizationSettingInDocument
from gooddata_api_client.model.json_api_organization_setting_out import JsonApiOrganizationSettingOut
from gooddata_api_client.model.json_api_organization_setting_out_document import JsonApiOrganizationSettingOutDocument
from gooddata_api_client.model.json_api_organization_setting_out_list import JsonApiOrganizationSettingOutList
from gooddata_api_client.model.json_api_organization_setting_out_with_links import JsonApiOrganizationSettingOutWithLinks
from gooddata_api_client.model.json_api_organization_setting_patch import JsonApiOrganizationSettingPatch
from gooddata_api_client.model.json_api_organization_setting_patch_document import JsonApiOrganizationSettingPatchDocument
from gooddata_api_client.model.json_api_theme_in import JsonApiThemeIn
from gooddata_api_client.model.json_api_theme_in_document import JsonApiThemeInDocument
from gooddata_api_client.model.json_api_theme_out import JsonApiThemeOut
from gooddata_api_client.model.json_api_theme_out_document import JsonApiThemeOutDocument
from gooddata_api_client.model.json_api_theme_out_list import JsonApiThemeOutList
from gooddata_api_client.model.json_api_theme_out_with_links import JsonApiThemeOutWithLinks
from gooddata_api_client.model.json_api_theme_patch import JsonApiThemePatch
from gooddata_api_client.model.json_api_theme_patch_document import JsonApiThemePatchDocument
from gooddata_api_client.model.json_api_user_group_in import JsonApiUserGroupIn
from gooddata_api_client.model.json_api_user_group_in_document import JsonApiUserGroupInDocument
from gooddata_api_client.model.json_api_user_group_in_relationships import JsonApiUserGroupInRelationships
from gooddata_api_client.model.json_api_user_group_in_relationships_parents import JsonApiUserGroupInRelationshipsParents
from gooddata_api_client.model.json_api_user_group_linkage import JsonApiUserGroupLinkage
from gooddata_api_client.model.json_api_user_group_out import JsonApiUserGroupOut
from gooddata_api_client.model.json_api_user_group_out_document import JsonApiUserGroupOutDocument
from gooddata_api_client.model.json_api_user_group_out_list import JsonApiUserGroupOutList
from gooddata_api_client.model.json_api_user_group_out_with_links import JsonApiUserGroupOutWithLinks
from gooddata_api_client.model.json_api_user_group_patch import JsonApiUserGroupPatch
from gooddata_api_client.model.json_api_user_group_patch_document import JsonApiUserGroupPatchDocument
from gooddata_api_client.model.json_api_user_group_to_many_linkage import JsonApiUserGroupToManyLinkage
from gooddata_api_client.model.json_api_user_group_to_one_linkage import JsonApiUserGroupToOneLinkage
from gooddata_api_client.model.json_api_user_in import JsonApiUserIn
from gooddata_api_client.model.json_api_user_in_attributes import JsonApiUserInAttributes
from gooddata_api_client.model.json_api_user_in_document import JsonApiUserInDocument
from gooddata_api_client.model.json_api_user_in_relationships import JsonApiUserInRelationships
from gooddata_api_client.model.json_api_user_linkage import JsonApiUserLinkage
from gooddata_api_client.model.json_api_user_out import JsonApiUserOut
from gooddata_api_client.model.json_api_user_out_document import JsonApiUserOutDocument
from gooddata_api_client.model.json_api_user_out_list import JsonApiUserOutList
from gooddata_api_client.model.json_api_user_out_with_links import JsonApiUserOutWithLinks
from gooddata_api_client.model.json_api_user_patch import JsonApiUserPatch
from gooddata_api_client.model.json_api_user_patch_document import JsonApiUserPatchDocument
from gooddata_api_client.model.json_api_user_setting_in import JsonApiUserSettingIn
from gooddata_api_client.model.json_api_user_setting_in_document import JsonApiUserSettingInDocument
from gooddata_api_client.model.json_api_user_setting_out import JsonApiUserSettingOut
from gooddata_api_client.model.json_api_user_setting_out_document import JsonApiUserSettingOutDocument
from gooddata_api_client.model.json_api_user_setting_out_list import JsonApiUserSettingOutList
from gooddata_api_client.model.json_api_user_setting_out_with_links import JsonApiUserSettingOutWithLinks
from gooddata_api_client.model.json_api_user_to_one_linkage import JsonApiUserToOneLinkage
from gooddata_api_client.model.json_api_visualization_object_in import JsonApiVisualizationObjectIn
from gooddata_api_client.model.json_api_visualization_object_in_document import JsonApiVisualizationObjectInDocument
from gooddata_api_client.model.json_api_visualization_object_linkage import JsonApiVisualizationObjectLinkage
from gooddata_api_client.model.json_api_visualization_object_out import JsonApiVisualizationObjectOut
from gooddata_api_client.model.json_api_visualization_object_out_document import JsonApiVisualizationObjectOutDocument
from gooddata_api_client.model.json_api_visualization_object_out_list import JsonApiVisualizationObjectOutList
from gooddata_api_client.model.json_api_visualization_object_out_with_links import JsonApiVisualizationObjectOutWithLinks
from gooddata_api_client.model.json_api_visualization_object_patch import JsonApiVisualizationObjectPatch
from gooddata_api_client.model.json_api_visualization_object_patch_document import JsonApiVisualizationObjectPatchDocument
from gooddata_api_client.model.json_api_visualization_object_to_many_linkage import JsonApiVisualizationObjectToManyLinkage
from gooddata_api_client.model.json_api_workspace_data_filter_in import JsonApiWorkspaceDataFilterIn
from gooddata_api_client.model.json_api_workspace_data_filter_in_attributes import JsonApiWorkspaceDataFilterInAttributes
from gooddata_api_client.model.json_api_workspace_data_filter_in_document import JsonApiWorkspaceDataFilterInDocument
from gooddata_api_client.model.json_api_workspace_data_filter_in_relationships import JsonApiWorkspaceDataFilterInRelationships
from gooddata_api_client.model.json_api_workspace_data_filter_in_relationships_filter_settings import JsonApiWorkspaceDataFilterInRelationshipsFilterSettings
from gooddata_api_client.model.json_api_workspace_data_filter_linkage import JsonApiWorkspaceDataFilterLinkage
from gooddata_api_client.model.json_api_workspace_data_filter_out import JsonApiWorkspaceDataFilterOut
from gooddata_api_client.model.json_api_workspace_data_filter_out_document import JsonApiWorkspaceDataFilterOutDocument
from gooddata_api_client.model.json_api_workspace_data_filter_out_list import JsonApiWorkspaceDataFilterOutList
from gooddata_api_client.model.json_api_workspace_data_filter_out_with_links import JsonApiWorkspaceDataFilterOutWithLinks
from gooddata_api_client.model.json_api_workspace_data_filter_patch import JsonApiWorkspaceDataFilterPatch
from gooddata_api_client.model.json_api_workspace_data_filter_patch_document import JsonApiWorkspaceDataFilterPatchDocument
from gooddata_api_client.model.json_api_workspace_data_filter_setting_linkage import JsonApiWorkspaceDataFilterSettingLinkage
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out import JsonApiWorkspaceDataFilterSettingOut
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_attributes import JsonApiWorkspaceDataFilterSettingOutAttributes
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_document import JsonApiWorkspaceDataFilterSettingOutDocument
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_list import JsonApiWorkspaceDataFilterSettingOutList
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_relationships import JsonApiWorkspaceDataFilterSettingOutRelationships
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_relationships_workspace_data_filter import JsonApiWorkspaceDataFilterSettingOutRelationshipsWorkspaceDataFilter
from gooddata_api_client.model.json_api_workspace_data_filter_setting_out_with_links import JsonApiWorkspaceDataFilterSettingOutWithLinks
from gooddata_api_client.model.json_api_workspace_data_filter_setting_to_many_linkage import JsonApiWorkspaceDataFilterSettingToManyLinkage
from gooddata_api_client.model.json_api_workspace_data_filter_to_one_linkage import JsonApiWorkspaceDataFilterToOneLinkage
from gooddata_api_client.model.json_api_workspace_in import JsonApiWorkspaceIn
from gooddata_api_client.model.json_api_workspace_in_attributes import JsonApiWorkspaceInAttributes
from gooddata_api_client.model.json_api_workspace_in_document import JsonApiWorkspaceInDocument
from gooddata_api_client.model.json_api_workspace_in_relationships import JsonApiWorkspaceInRelationships
from gooddata_api_client.model.json_api_workspace_in_relationships_parent import JsonApiWorkspaceInRelationshipsParent
from gooddata_api_client.model.json_api_workspace_linkage import JsonApiWorkspaceLinkage
from gooddata_api_client.model.json_api_workspace_out import JsonApiWorkspaceOut
from gooddata_api_client.model.json_api_workspace_out_document import JsonApiWorkspaceOutDocument
from gooddata_api_client.model.json_api_workspace_out_list import JsonApiWorkspaceOutList
from gooddata_api_client.model.json_api_workspace_out_meta import JsonApiWorkspaceOutMeta
from gooddata_api_client.model.json_api_workspace_out_meta_config import JsonApiWorkspaceOutMetaConfig
from gooddata_api_client.model.json_api_workspace_out_with_links import JsonApiWorkspaceOutWithLinks
from gooddata_api_client.model.json_api_workspace_patch import JsonApiWorkspacePatch
from gooddata_api_client.model.json_api_workspace_patch_document import JsonApiWorkspacePatchDocument
from gooddata_api_client.model.json_api_workspace_setting_in import JsonApiWorkspaceSettingIn
from gooddata_api_client.model.json_api_workspace_setting_in_document import JsonApiWorkspaceSettingInDocument
from gooddata_api_client.model.json_api_workspace_setting_out import JsonApiWorkspaceSettingOut
from gooddata_api_client.model.json_api_workspace_setting_out_document import JsonApiWorkspaceSettingOutDocument
from gooddata_api_client.model.json_api_workspace_setting_out_list import JsonApiWorkspaceSettingOutList
from gooddata_api_client.model.json_api_workspace_setting_out_with_links import JsonApiWorkspaceSettingOutWithLinks
from gooddata_api_client.model.json_api_workspace_setting_patch import JsonApiWorkspaceSettingPatch
from gooddata_api_client.model.json_api_workspace_setting_patch_document import JsonApiWorkspaceSettingPatchDocument
from gooddata_api_client.model.json_api_workspace_to_one_linkage import JsonApiWorkspaceToOneLinkage
from gooddata_api_client.model.label_identifier import LabelIdentifier
from gooddata_api_client.model.list_links import ListLinks
from gooddata_api_client.model.list_links_all_of import ListLinksAllOf
from gooddata_api_client.model.measure_definition import MeasureDefinition
from gooddata_api_client.model.measure_execution_result_header import MeasureExecutionResultHeader
from gooddata_api_client.model.measure_group_headers import MeasureGroupHeaders
from gooddata_api_client.model.measure_header_out import MeasureHeaderOut
from gooddata_api_client.model.measure_item import MeasureItem
from gooddata_api_client.model.measure_result_header import MeasureResultHeader
from gooddata_api_client.model.measure_value_filter import MeasureValueFilter
from gooddata_api_client.model.negative_attribute_filter import NegativeAttributeFilter
from gooddata_api_client.model.negative_attribute_filter_negative_attribute_filter import NegativeAttributeFilterNegativeAttributeFilter
from gooddata_api_client.model.object_links import ObjectLinks
from gooddata_api_client.model.object_links_container import ObjectLinksContainer
from gooddata_api_client.model.paging import Paging
from gooddata_api_client.model.parameter import Parameter
from gooddata_api_client.model.platform_usage import PlatformUsage
from gooddata_api_client.model.platform_usage_request import PlatformUsageRequest
from gooddata_api_client.model.pop_dataset import PopDataset
from gooddata_api_client.model.pop_dataset_measure_definition import PopDatasetMeasureDefinition
from gooddata_api_client.model.pop_dataset_measure_definition_previous_period_measure import PopDatasetMeasureDefinitionPreviousPeriodMeasure
from gooddata_api_client.model.pop_date import PopDate
from gooddata_api_client.model.pop_date_measure_definition import PopDateMeasureDefinition
from gooddata_api_client.model.pop_date_measure_definition_over_period_measure import PopDateMeasureDefinitionOverPeriodMeasure
from gooddata_api_client.model.pop_measure_definition import PopMeasureDefinition
from gooddata_api_client.model.positive_attribute_filter import PositiveAttributeFilter
from gooddata_api_client.model.positive_attribute_filter_positive_attribute_filter import PositiveAttributeFilterPositiveAttributeFilter
from gooddata_api_client.model.range_measure_value_filter import RangeMeasureValueFilter
from gooddata_api_client.model.range_measure_value_filter_range_measure_value_filter import RangeMeasureValueFilterRangeMeasureValueFilter
from gooddata_api_client.model.ranking_filter import RankingFilter
from gooddata_api_client.model.ranking_filter_ranking_filter import RankingFilterRankingFilter
from gooddata_api_client.model.reference_identifier import ReferenceIdentifier
from gooddata_api_client.model.relative_date_filter import RelativeDateFilter
from gooddata_api_client.model.relative_date_filter_relative_date_filter import RelativeDateFilterRelativeDateFilter
from gooddata_api_client.model.resolve_settings_request import ResolveSettingsRequest
from gooddata_api_client.model.rest_api_identifier import RestApiIdentifier
from gooddata_api_client.model.result_cache_metadata import ResultCacheMetadata
from gooddata_api_client.model.result_dimension import ResultDimension
from gooddata_api_client.model.result_dimension_header import ResultDimensionHeader
from gooddata_api_client.model.result_spec import ResultSpec
from gooddata_api_client.model.scan_request import ScanRequest
from gooddata_api_client.model.scan_result_pdm import ScanResultPdm
from gooddata_api_client.model.settings import Settings
from gooddata_api_client.model.simple_measure_definition import SimpleMeasureDefinition
from gooddata_api_client.model.simple_measure_definition_measure import SimpleMeasureDefinitionMeasure
from gooddata_api_client.model.sort_key import SortKey
from gooddata_api_client.model.sort_key_attribute import SortKeyAttribute
from gooddata_api_client.model.sort_key_attribute_attribute import SortKeyAttributeAttribute
from gooddata_api_client.model.sort_key_total import SortKeyTotal
from gooddata_api_client.model.sort_key_total_total import SortKeyTotalTotal
from gooddata_api_client.model.sort_key_value import SortKeyValue
from gooddata_api_client.model.sort_key_value_value import SortKeyValueValue
from gooddata_api_client.model.table_warning import TableWarning
from gooddata_api_client.model.tabular_export_request import TabularExportRequest
from gooddata_api_client.model.tabular_export_result import TabularExportResult
from gooddata_api_client.model.test_definition_request import TestDefinitionRequest
from gooddata_api_client.model.test_query_duration import TestQueryDuration
from gooddata_api_client.model.test_request import TestRequest
from gooddata_api_client.model.test_response import TestResponse
from gooddata_api_client.model.total import Total
from gooddata_api_client.model.total_dimension import TotalDimension
from gooddata_api_client.model.total_execution_result_header import TotalExecutionResultHeader
from gooddata_api_client.model.total_result_header import TotalResultHeader
from gooddata_api_client.model.user_group_identifier import UserGroupIdentifier
from gooddata_api_client.model.workspace_identifier import WorkspaceIdentifier



"""
    OpenAPI definition

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v0
    Contact: support@gooddata.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

NAME = "gooddata-api-client"
VERSION = "1.2.1a2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="OpenAPI definition",
    author="GoodData (generated by OpenAPI Generator)",
    author_email="support@gooddata.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "OpenAPI definition"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    license_file="LICENSE.txt",
    license_files=("LICENSE.txt",),
    long_description=long_description,
    long_description_content_type="text/markdown",
)
